%define pypi_name SQLAlchemy

%bcond_with check

Summary:	SQL toolkit and object relational mapper for Python
Name:		python-sqlalchemy
Version:	2.0.31
Release:	%mkrel 1
License:	MIT
Group:		Development/Python
URL:		https://www.sqlalchemy.org/
Source0:	%{pypi_source}
BuildRequires:	pyproject-rpm-macros
BuildRequires:	python3-devel
%if %{with check}
# JSON enabled sqlite is needed for tests
BuildRequires:	pkgconfig(sqlite3) >= 3.29.0-2
# Tests
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(pytest-xdist)
%endif

%description
SQLAlchemy is an Object Relational Mappper (ORM) that provides a flexible,
high-level interface to SQL databases. Database and domain concepts are
decoupled, allowing both sides maximum flexibility and power. SQLAlchemy
provides a powerful mapping layer that can work as automatically or as manually
as you choose, determining relationships based on foreign keys or letting you
define the join conditions explicitly, to bridge the gap between database and
domain.

%package -n python3-sqlalchemy
Summary:	Modular and flexible ORM library for python
Group:		Development/Python
%{?python_provide:%python_provide python3-sqlalchemy}

%description -n python3-sqlalchemy
SQLAlchemy is an Object Relational Mappper (ORM) that provides a flexible,
high-level interface to SQL databases. Database and domain concepts are
decoupled, allowing both sides maximum flexibility and power. SQLAlchemy
provides a powerful mapping layer that can work as automatically or as manually
as you choose, determining relationships based on foreign keys or letting you
define the join conditions explicitly, to bridge the gap between database and
domain.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}
# Relax dependencies
sed -i "s/greenlet != 0.4/greenlet >= 0.4/" setup.cfg

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files sqlalchemy

%if %{with check}
%check
%pytest
%endif

%files -n python3-sqlalchemy -f %{pyproject_files}
%license LICENSE
%doc examples


%changelog
* Tue Jul 02 2024 papoteur <papoteur> 2.0.31-1.mga10
+ Revision: 2078917
- new version 2.0.31

* Mon Apr 15 2024 papoteur <papoteur> 2.0.29-1.mga10
+ Revision: 2057799
- new version 2.0.29

* Thu Dec 28 2023 wally <wally> 2.0.23-1.mga10
+ Revision: 2023294
- new version 2.0.23
- use pyproject rpm macros

* Fri Nov 25 2022 papoteur <papoteur> 1.4.44-2.mga9
+ Revision: 1910972
- relax requirements on greenlet

* Sun Nov 20 2022 papoteur <papoteur> 1.4.44-1.mga9
+ Revision: 1909548
- new 1.4.44
+ neoclust <neoclust>
- New version 1.4.41
- New version 	1.4.40

* Sat Mar 19 2022 umeabot <umeabot> 1.3.23-3.mga9
+ Revision: 1799176
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 tv <tv> 1.3.23-2.mga9
+ Revision: 1778493
- Rebuild for python-3.10

* Sat Mar 20 2021 joequant <joequant> 1.3.23-1.mga9
+ Revision: 1705794
- add source file
- add patch to fix test
- update to 1.3.23
+ neoclust <neoclust>
- Rebuild against python 3.9

* Fri Oct 30 2020 joequant <joequant> 1.3.20-1.mga8
+ Revision: 1640652
- update to 1.3.20

* Fri Sep 18 2020 joequant <joequant> 1.3.19-1.mga8
+ Revision: 1628591
- bump
- fix sqlalchemy build - don't regenerate docs
  Regenerating the docs will cause an error when running sphinx 3.1.
  This changes the build to use the pregenerated docs.  Also upgrading
  to newest version which should be okay because of the regression tests.
+ daviddavid <daviddavid>
- new version: 1.3.15

* Thu Feb 20 2020 umeabot <umeabot> 1.3.13-2.mga8
+ Revision: 1546104
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 daviddavid <daviddavid> 1.3.13-1.mga8
+ Revision: 1485931
- new version: 1.3.13

* Wed Dec 25 2019 daviddavid <daviddavid> 1.3.12-1.mga8
+ Revision: 1469950
- new version: 1.3.12

* Sat Nov 23 2019 daviddavid <daviddavid> 1.3.11-1.mga8
+ Revision: 1462300
- new version: 1.3.11

* Wed Nov 13 2019 daviddavid <daviddavid> 1.3.10-1.mga8
+ Revision: 1459736
- fix/skip tests that are broken on SQLite 3.30
- new version: 1.3.10

* Sun Sep 15 2019 tv <tv> 1.3.8-2.mga8
+ Revision: 1441261
- rebuild for python-3.8

* Sat Aug 31 2019 wally <wally> 1.3.8-1.mga8
+ Revision: 1435836
- new version 1.3.8
- drop python2 support

* Sat Jan 05 2019 wally <wally> 1.2.12-2.mga7
+ Revision: 1349790
- rebuild for python3.7

* Thu Nov 01 2018 kekepower <kekepower> 1.2.12-1.mga7
+ Revision: 1327238
- Update to version 1.2.12
- Renamed python-sqlalchemy
- Use python_provides

* Sun Sep 09 2018 wally <wally> 1.1.4-3.mga7
+ Revision: 1258039
- skip failing test_round_trip_direct_type_affinity test for now
- add test fixes from Fedora
- drop unneeded sqlite3 lib BR pulled by devel pkg
- update provides exclude syntax

* Sat Aug 05 2017 pterjan <pterjan> 1.1.4-2.mga7
+ Revision: 1135650
- Rebuild for python 3.6

* Sun Nov 27 2016 philippem <philippem> 1.1.4-1.mga6
+ Revision: 1070407
- update to 1.1.4

* Tue May 17 2016 philippem <philippem> 1.0.13-1.mga6
+ Revision: 1016371
- update to 1.0.13

* Sat Apr 09 2016 shlomif <shlomif> 1.0.12-3.mga6
+ Revision: 999850
- Hopefully fix BR
- Reenable the tests for new sqlite3

* Mon Apr 04 2016 shlomif <shlomif> 1.0.12-2.mga6
+ Revision: 998323
- Avoid running the tests for the current version, due to the new sqlite.

* Tue Feb 16 2016 philippem <philippem> 1.0.12-1.mga6
+ Revision: 962577
- update to 1.0.12

* Wed Dec 23 2015 philippem <philippem> 1.0.11-1.mga6
+ Revision: 913855
- update to 1.0.11

* Sat Dec 19 2015 philippem <philippem> 1.0.10-1.mga6
+ Revision: 912171
- update to 1.0.10

* Thu Oct 29 2015 tv <tv> 1.0.9-1.mga6
+ Revision: 896216
- new release

* Fri Oct 09 2015 shlomif <shlomif> 1.0.8-2.mga6
+ Revision: 888347
- Rebuild for new Python3 (3.5.x)

* Fri Aug 28 2015 philippem <philippem> 1.0.8-1.mga6
+ Revision: 870572
- update to 1.0.8

* Wed Oct 15 2014 umeabot <umeabot> 0.9.7-4.mga5
+ Revision: 747420
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.9.7-3.mga5
+ Revision: 729827
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.9.7-2.mga5
+ Revision: 688349
- Mageia 5 Mass Rebuild

* Thu Aug 07 2014 philippem <philippem> 0.9.7-1.mga5
+ Revision: 660836
- update to 0.9.7

* Thu Jul 03 2014 philippem <philippem> 0.9.6-1.mga5
+ Revision: 642777
- update to 0.9.6

* Tue Jun 03 2014 philippem <philippem> 0.9.4-1.mga5
+ Revision: 632655
- update to 0.9.4
+ pterjan <pterjan>
- Rebuild for new Python

* Mon Mar 17 2014 philippem <philippem> 0.9.3-1.mga5
+ Revision: 604539
- Update to 0.9.3

* Tue Oct 22 2013 umeabot <umeabot> 0.8.2-3.mga4
+ Revision: 544352
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.8.2-2.mga4
+ Revision: 499431
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Jul 10 2013 philippem <philippem> 0.8.2-1.mga4
+ Revision: 452446
- Update to 0.8.2, add Python 3

* Sat Feb 16 2013 philippem <philippem> 0.7.10-1.mga3
+ Revision: 398743
- Update to new upstream

* Sun Jan 13 2013 umeabot <umeabot> 0.7.9-2.mga3
+ Revision: 379545
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 23 2012 philippem <philippem> 0.7.9-1.mga3
+ Revision: 334189
- Update to 0.7.9

* Sat Dec 17 2011 philippem <philippem> 0.7.4-1.mga2
+ Revision: 183152
- Update to 0.7.4

* Fri Nov 18 2011 philippem <philippem> 0.7.3-1.mga2
+ Revision: 168699
- Update to 0.7.3

* Wed Sep 21 2011 philippem <philippem> 0.7.2-1.mga2
+ Revision: 146407
- 0.7.2 Upstream release
- use sqla_nose.py to fix %%check

* Fri Apr 08 2011 philippem <philippem> 0.6.6-1.mga1
+ Revision: 82011
- imported package python-sqlalchemy


* Thu Apr 07 2011 Philippe Makowski <makowski.mageia@gmail.com> 0.6.6-1mga1
- Update to 0.6.6
- Add cextensions
- Imported from Mandriva

* Mon Nov 01 2010 Funda Wang <fwang@mandriva.org> 0.6.4-3mdv2011.0
+ Revision: 591429
- rebuild for py 2.7

* Sat Oct 30 2010 Michael Scherer <misc@mandriva.org> 0.6.4-2mdv2011.0
+ Revision: 590593
- rebuild for python 2.7

* Tue Sep 07 2010 Lev Givon <lev@mandriva.org> 0.6.4-1mdv2011.0
+ Revision: 576682
- Update to 0.6.4.
- Update to 0.6.2.
- Update to 0.6.1.

* Mon Jan 18 2010 Frederik Himpe <fhimpe@mandriva.org> 0.5.8-1mdv2010.1
+ Revision: 493276
- update to new version 0.5.8

* Tue Dec 29 2009 Frederik Himpe <fhimpe@mandriva.org> 0.5.7-1mdv2010.1
+ Revision: 483307
- update to new version 0.5.7

* Mon Sep 14 2009 Lev Givon <lev@mandriva.org> 0.5.6-1mdv2010.0
+ Revision: 441080
- Update to 0.5.6.

* Tue Jul 14 2009 Frederik Himpe <fhimpe@mandriva.org> 0.5.5-1mdv2010.0
+ Revision: 396016
- update to new version 0.5.5

* Wed May 27 2009 Frederik Himpe <fhimpe@mandriva.org> 0.5.4p2-1mdv2010.0
+ Revision: 380279
- update to new version 0.5.4p2

* Mon May 18 2009 Frederik Himpe <fhimpe@mandriva.org> 0.5.4p1-1mdv2010.0
+ Revision: 377349
- update to new version 0.5.4p1

* Sat May 02 2009 Frederik Himpe <fhimpe@mandriva.org> 0.5.3-1mdv2010.0
+ Revision: 370658
- update to new version 0.5.3

* Sun Mar 15 2009 Michael Scherer <misc@mandriva.org> 0.5.2-1mdv2009.1
+ Revision: 355347
- update to new version
- do not hardcode the module name everywhere
- use a different source url to ease update with mdvsys

* Fri Jan 02 2009 Funda Wang <fwang@mandriva.org> 0.4.8-2mdv2009.1
+ Revision: 323373
- rebuild

* Thu Nov 13 2008 Oden Eriksson <oeriksson@mandriva.com> 0.4.8-1mdv2009.1
+ Revision: 302684
- 0.4.8

* Thu Sep 04 2008 Jérôme Soyer <saispo@mandriva.org> 0.4.7p1-1mdv2009.0
+ Revision: 280565
- New version

* Fri Aug 08 2008 Thierry Vignaud <tv@mandriva.org> 0.4.6-2mdv2009.0
+ Revision: 269043
- rebuild early 2009.0 package (before pixel changes)

* Wed Jun 11 2008 Lev Givon <lev@mandriva.org> 0.4.6-1mdv2009.0
+ Revision: 218094
- Update to 0.4.6.

* Thu Feb 21 2008 Oden Eriksson <oeriksson@mandriva.com> 0.3.11-1mdv2008.1
+ Revision: 173632
- fix build deps (duh!)
- import python-sqlalchemy


* Thu Feb 21 2008 Oden Eriksson <oeriksson@mandriva.com> 0.3.11-1mdv2008.1
- initial Mandriva package

* Sun Jan 20 2008 Oden Eriksson <oeriksson@mandriva.com> 0.3.11-1.RHEL4
- initial Redhat RHEL4 package.
